@@ -25,16 +25,9 @@ This is the common code for database support; specific databases are
 supported in modules in L{storm.databases}.
 """
 
-from __future__ import print_function
-
-try:
-    from collections.abc import Callable
-except ImportError:
-    from collections import Callable
+from collections.abc import Callable
 from functools import wraps
 
-import six
-
 from storm.expr import Expr, State, compile
 # Circular import: imported at the end of the module.
 # from storm.tracer import trace
@@ -56,7 +49,7 @@ STATE_DISCONNECTED = 2
 STATE_RECONNECT = 3
 
 
-class Result(object):
+class Result:
     """A representation of the results from a single SQL statement."""
 
     _closed = False
@@ -171,12 +164,12 @@ class Result(object):
         return row
 
 
-class CursorWrapper(object):
+class CursorWrapper:
     """A DB-API cursor, wrapping exceptions as StormError instances."""
 
     def __init__(self, cursor, database):
-        super(CursorWrapper, self).__setattr__('_cursor', cursor)
-        super(CursorWrapper, self).__setattr__('_database', database)
+        super().__setattr__('_cursor', cursor)
+        super().__setattr__('_database', database)
 
     def __getattr__(self, name):
         attr = getattr(self._cursor, name)
@@ -195,8 +188,7 @@ class CursorWrapper(object):
 
     def __iter__(self):
         with wrap_exceptions(self._database):
-            for item in self._cursor:
-                yield item
+            yield from self._cursor
 
     def __enter__(self):
         return self
@@ -206,7 +198,7 @@ class CursorWrapper(object):
             self.close()
 
 
-class ConnectionWrapper(object):
+class ConnectionWrapper:
     """A DB-API connection, wrapping exceptions as StormError instances."""
 
     def __init__(self, connection, database):
@@ -243,7 +235,7 @@ class ConnectionWrapper(object):
             return CursorWrapper(self._connection.cursor(), self._database)
 
 
-class Connection(object):
+class Connection:
     """A connection to a database.
 
     @cvar result_factory: A callable which takes this L{Connection}
@@ -377,7 +369,7 @@ class Connection(object):
             self._check_disconnect(trace, "connection_commit", self, xid)
 
     def recover(self):
-        """Return a list of L{Xid}\ s representing pending transactions."""
+        """Return a list of L{Xid}\\ s representing pending transactions."""
         self._ensure_connected()
         raw_xids = self._check_disconnect(self._raw_connection.tpc_recover)
         return [Xid(raw_xid[0], raw_xid[1], raw_xid[2])
@@ -423,7 +415,7 @@ class Connection(object):
         is not intended to be used externally.
 
         This delegates conversion to any
-        L{Variable <storm.variable.Variable>}\ s in the parameter list, and
+        L{Variable <storm.variable.Variable>}\\ s in the parameter list, and
         passes through all other values untouched.
         """
         for param in params:
@@ -551,7 +543,7 @@ class Connection(object):
         """
 
 
-class Database(object):
+class Database:
     """A database that can be connected to.
 
     This should be subclassed for individual database backends.
@@ -690,7 +682,7 @@ def create_database(uri):
         Where 'anything' has previously been registered with
         L{register_scheme}.
     """
-    if isinstance(uri, six.string_types):
+    if isinstance(uri, str):
         uri = URI(uri)
     if uri.scheme in _database_schemes:
         factory = _database_schemes[uri.scheme]
