@@ -19,12 +19,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from __future__ import print_function
 
-import six
-
-
-class Dummy(object):
+class Dummy:
     """Magic "infectious" class.
 
     This class simplifies nice errors on the creation of
@@ -43,7 +39,4 @@ class Dummy(object):
     def __bool__(self):
         return False
 
-    if six.PY2:
-        __nonzero__ = __bool__
-
 dummy = Dummy()
